@@ -325,13 +325,15 @@ class Schemas:
         "properties": {
             "device_one_time_keys_count": {
                 "type": "object",
+                "default": {},
                 "properties": {
-                    "curve25519": {"type": "integer", "default": 0},
-                    "signed_curve25519": {"type": "integer", "default": 0},
+                    "curve25519": {"type": "integer"},
+                    "signed_curve25519": {"type": "integer"},
                 }
             },
             "device_lists": {
                 "type": "object",
+                "default": {},
                 "properties": {
                     "changed": {"type": "array", "items": {"type": "string"}},
                     "left": {"type": "array", "items": {"type": "string"}}
@@ -340,28 +342,32 @@ class Schemas:
             "next_batch": {"type": "string"},
             "rooms": {
                 "type": "object",
+                "default": {},
                 "properties": {
                     "invite": {
                         "type": "object",
+                        "default": {},
                         "patternProperties": {
                             RoomRegex: {
                                 "type": "object",
                                 "properties": {
                                     "invite_state": {
                                         "type": "object",
+                                        "default": {},
                                         "properties": {
-                                            "events": {"type": "array"}
+                                            "events": {
+                                                "type": "array",
+                                                "default": [],
+                                            }
                                         },
-                                        "required": ["events"]
                                     }
                                 },
-                                "required": ["invite_state"]
                             }
                         },
-                        "additionalProperties": False,
                     },
                     "join": {
                         "type": "object",
+                        "default": {},
                         "patternProperties": {
                             RoomRegex: {
                                 "type": "object",
@@ -369,17 +375,23 @@ class Schemas:
                                     "timeline": room_timeline,
                                     "state": {
                                         "type": "object",
+                                        "default": {},
                                         "properties": {
-                                            "events": {"type": "array"}
+                                            "events": {
+                                                "type": "array",
+                                                "default": [],
+                                            },
                                         },
-                                        "required": ["events"]
                                     },
                                     "ephemeral": {
                                         "type": "object",
+                                        "default": {},
                                         "properties": {
-                                            "events": {"type": "array"}
+                                            "events": {
+                                                "type": "array",
+                                                "default": [],
+                                            }
                                         },
-                                        "required": ["events"]
                                     },
                                     "summary": {
                                         "type": "object",
@@ -398,71 +410,67 @@ class Schemas:
                                     },
                                     "account_data": {
                                         "type": "object",
+                                        "default": {},
                                         "properties": {
-                                            "events": {"type": "array"}
+                                            "events": {
+                                                "type": "array",
+                                                "default": [],
+                                            },
                                         },
-                                        "required": ["events"]
                                     },
                                 },
-                                "required": [
-                                    "timeline",
-                                    "state",
-                                    "ephemeral",
-                                    "account_data",
-                                ]
                             }
                         },
-                        "additionalProperties": False,
                     },
                     "leave": {
                         "type": "object",
+                        "default": {},
                         "patternProperties": {
                             RoomRegex: {
                                 "type": "object",
                                 "properties": {
                                     "timeline": {
                                         "type": "object",
+                                        "default": {},
                                         "properties": {
-                                            "events": {"type": "array"}
+                                            "events": {
+                                                "type": "array",
+                                                "default": [],
+                                            },
                                         },
-                                        "required": ["events"]
                                     },
                                     "state": {
                                         "type": "object",
+                                        "default": {},
                                         "properties": {
-                                            "events": {"type": "array"}
+                                            "events": {
+                                                "type": "array",
+                                                "default": [],
+                                            },
                                         },
-                                        "required": ["events"]
                                     }
                                 },
-                                "required": ["timeline", "state"]
                             }
                         },
-                        "additionalProperties": False,
                     },
                 },
             },
             "to_device": {
                 "type": "object",
+                "default": {},
                 "properties": {
-                    "events": {"type": "array"}
+                    "events": {"type": "array", "default": []}
                 },
-                "required": ["events"]
             },
             "presence": {
                 "type": "object",
+                "default": {},
                 "properties": {
-                    "events": {"type": "array"}
+                    "events": {"type": "array", "default": []},
                 },
-                "required": ["events"]
             }
         },
-        "required": [
-            "next_batch",
-            "device_one_time_keys_count",
-            "rooms",
-            "to_device",
-        ],
+        "required": ["next_batch"],
     }
 
     room_event = {
@@ -985,7 +993,6 @@ class Schemas:
                         "patternProperties": {
                             EventTypeRegex: {"type": "integer"}
                         },
-                        "additionalProperties": False,
                     },
                     "users": {
                         "type": "object",
@@ -993,7 +1000,6 @@ class Schemas:
                         "patternProperties": {
                             UserIdRegex: {"type": "integer"}
                         },
-                        "additionalProperties": False,
                     },
                     "notifications": {
                         "type": "object",
@@ -1001,7 +1007,6 @@ class Schemas:
                         "properties": {
                             "room": {"type": "integer", "default": 50},
                         },
-                        "additionalProperties": {"type": "integer"},
                     },
                 },
             },
@@ -1057,6 +1062,22 @@ class Schemas:
         "required": ["sender", "redacts"],
     }
 
+    sticker = {
+        "type": "object",
+        "properties": {
+            "sender": {"type": "string", "format": "user_id"},
+            "content": {
+                "type": "object",
+                "properties": {
+                    "body": {"type": "string"},
+                    "url": {"type": "string"},
+                },
+                "required": ["body", "url"],
+            },
+        },
+        "required": ["sender"],
+    }
+
     room_resolve_alias = {
         "type": "object",
         "properties": {
@@ -1071,14 +1092,12 @@ class Schemas:
         "type": "object",
         "properties": {"event_id": {"type": "string"}},
         "required": ["event_id"],
-        "additionalProperties": False,
     }
 
     room_id = {
         "type": "object",
         "properties": {"room_id": {"type": "string"}},
         "required": ["room_id"],
-        "additionalProperties": False,
     }
 
     room_create_response = {
@@ -1095,7 +1114,6 @@ class Schemas:
             "end": {"type": "string"},
         },
         "required": ["chunk", "start", "end"],
-        "additionalProperties": False,
     }
 
     room_context = {
@@ -1116,7 +1134,6 @@ class Schemas:
             "events_after",
             "event",
         ],
-        "additionalProperties": False,
     }
 
     invite_event = {
@@ -1154,7 +1171,6 @@ class Schemas:
             "room_id": {"type": "string"}
         },
         "required": ["content", "type"],
-        "additionalProperties": False,
     }
 
     m_receipt = {
@@ -1186,7 +1202,6 @@ class Schemas:
             "room_id": {"type": "string"}
         },
         "required": ["content", "type"],
-        "additionalProperties": True,
     }
 
     keys_upload = {
@@ -1627,7 +1642,6 @@ class Schemas:
         "type": "object",
         "properties": {"content_uri": {"type": "string"}},
         "required": ["content_uri"],
-        "additionalProperties": False,
     }
 
     content_repository_config = {
